@@ -86,7 +86,7 @@
         if (this._addExtensionCallback) {
           extensions.forEach(this._addExtensionCallback);
         } else {
-          this._pendingExtensionDescriptors.pushAll(extensions);
+          this._pendingExtensionDescriptors.push(...extensions);
         }
       }
     }
@@ -294,6 +294,8 @@
      * @param {string} tabId
      */
     setInspectedTabId(tabId) {
+      this._inspectedTabIdValue = tabId;
+
       // Support for legacy front-ends (<M41).
       if (window['WebInspector'] && window['WebInspector']['setInspectedTabId']) {
         window['WebInspector']['setInspectedTabId'](tabId);
@@ -302,6 +304,13 @@
       }
     }
 
+    /**
+     * @return {string|undefined}
+     */
+    getInspectedTabId() {
+      return this._inspectedTabIdValue;
+    }
+
     /**
      * @param {boolean} useSoftMenu
      */
@@ -335,10 +344,9 @@
       request.send(null);
       if (request.status === 200) {
         return request.responseText;
-      } else {
-        console.error('Error while decoding chunk in streamWrite');
-        return '';
       }
+      console.error('Error while decoding chunk in streamWrite');
+      return '';
     }
   };
 
@@ -618,7 +626,7 @@
      * @override
      * @param {string} fileSystemId
      * @param {string} registeredName
-     * @return {?DOMFileSystem}
+     * @return {?FileSystem}
      */
     isolatedFileSystem(fileSystemId, registeredName) {
       return DevToolsHost.isolatedFileSystem(fileSystemId, registeredName);
@@ -933,7 +941,7 @@
       'emulation.deviceScaleFactor',
       'emulation.deviceUA',
       'emulation.deviceWidth',
-      'emulation.geolocationOverride',
+      'emulation.locationOverride',
       'emulation.showDeviceMode',
       'emulation.showRulers',
       'enableAsyncStackTraces',
@@ -952,7 +960,6 @@
       'hideCollectedPromises',
       'hideNetworkMessages',
       'highlightNodeOnHoverInOverlay',
-      'highResolutionCpuProfiling',
       'inlineVariableValues',
       'Inspector.drawerSplitView',
       'Inspector.drawerSplitViewState',
